@@ -28,13 +28,9 @@
 #include "bookmark.h"
 #include "settings.h"
 #include "window.h"
-#include "mountoperation.h"
 
 typedef struct _GigoloBackendGVFSPrivate			GigoloBackendGVFSPrivate;
 
-#define GIGOLO_BACKEND_GVFS_GET_PRIVATE(obj)		(G_TYPE_INSTANCE_GET_PRIVATE((obj),\
-			GIGOLO_BACKEND_GVFS_TYPE, GigoloBackendGVFSPrivate))
-
 enum
 {
     PROP_0,
@@ -97,7 +93,7 @@ static void browse_network_real						(BrowseData *bd);
 static void browse_host_real						(BrowseData *bd);
 
 
-G_DEFINE_TYPE(GigoloBackendGVFS, gigolo_backend_gvfs, G_TYPE_OBJECT);
+G_DEFINE_TYPE_WITH_PRIVATE(GigoloBackendGVFS, gigolo_backend_gvfs, G_TYPE_OBJECT);
 
 
 
@@ -147,8 +143,6 @@ static void gigolo_backend_gvfs_class_init(GigoloBackendGVFSClass *klass)
 	g_object_class->finalize = gigolo_backend_gvfs_finalize;
 	g_object_class->set_property = gigolo_backend_gvfs_set_property;
 
-	g_type_class_add_private(klass, sizeof(GigoloBackendGVFSPrivate));
-
 	g_object_class_install_property(g_object_class,
 										PROP_PARENT,
 										g_param_spec_object(
@@ -212,7 +206,7 @@ static void gigolo_backend_gvfs_finalize(GObject *object)
 static gchar *get_tooltip_text(GigoloBackendGVFS *backend, gpointer ref, gint ref_type, const gchar *type)
 {
 	gchar *result = NULL;
-	GigoloBackendGVFSPrivate *priv = GIGOLO_BACKEND_GVFS_GET_PRIVATE(backend);
+	GigoloBackendGVFSPrivate *priv = gigolo_backend_gvfs_get_instance_private(backend);
 	switch (ref_type)
 	{
 		case GIGOLO_WINDOW_REF_TYPE_MOUNT:
@@ -270,7 +264,7 @@ static void mount_volume_changed_cb(GVolumeMonitor *vm, G_GNUC_UNUSED GMount *mn
 	GtkTreeIter iter;
 	gchar *vol_name, *mount_name, *display_name, *scheme, *uri, *tooltip_text;
 	const gchar *scheme_name;
-	GigoloBackendGVFSPrivate *priv = GIGOLO_BACKEND_GVFS_GET_PRIVATE(backend);
+	GigoloBackendGVFSPrivate *priv = gigolo_backend_gvfs_get_instance_private(backend);
 	GigoloBookmark *bookmark;
 	GigoloSettings *settings = gigolo_window_get_settings(GIGOLO_WINDOW(priv->parent));
 
@@ -365,7 +359,7 @@ static void mount_volume_changed_cb(GVolumeMonitor *vm, G_GNUC_UNUSED GMount *mn
 static void gigolo_backend_gvfs_set_property(GObject *object, guint prop_id,
 											 const GValue *value, GParamSpec *pspec)
 {
-	GigoloBackendGVFSPrivate *priv = GIGOLO_BACKEND_GVFS_GET_PRIVATE(object);
+	GigoloBackendGVFSPrivate *priv = gigolo_backend_gvfs_get_instance_private(GIGOLO_BACKEND_GVFS(object));
 
 	switch (prop_id)
 	{
@@ -513,7 +507,7 @@ gboolean gigolo_backend_gvfs_mount_volume(GigoloBackendGVFS *backend, GtkWindow
 
 	if (! G_IS_MOUNT(vol) && G_IS_VOLUME(vol) && g_volume_can_mount(G_VOLUME(vol)))
 	{
-		GMountOperation *op = gigolo_mount_operation_new(window);
+		GMountOperation *op = gtk_mount_operation_new(window);
 
 		g_volume_mount(G_VOLUME(vol), G_MOUNT_MOUNT_NONE, op, NULL, volume_mount_finished_cb, backend);
 
@@ -535,7 +529,7 @@ void gigolo_backend_gvfs_unmount_mount(GigoloBackendGVFS *backend, gpointer moun
 	g_return_if_fail(mount != NULL);
 
 #if GLIB_CHECK_VERSION(2, 22, 0)
-	op = gigolo_mount_operation_new(parent);
+	op = gtk_mount_operation_new(parent);
 	g_mount_unmount_with_operation(
 		G_MOUNT(mount), G_MOUNT_UNMOUNT_NONE, op, NULL, unmount_finished_cb, backend);
 	g_object_unref(op);
@@ -593,7 +587,7 @@ void gigolo_backend_gvfs_mount_uri(GigoloBackendGVFS *backend, const gchar *uri,
 	g_return_if_fail(uri != NULL);
 	g_return_if_fail(backend != NULL);
 
-	op = gigolo_mount_operation_new(GTK_WINDOW(parent));
+	op = gtk_mount_operation_new(GTK_WINDOW(parent));
 	file = g_file_new_for_uri(uri);
 	mi = g_new0(MountInfo, 1);
 	mi->self = backend;
@@ -636,7 +630,7 @@ gchar *gigolo_backend_gvfs_get_mount_path(gpointer mount)
 static gboolean browse_network_ready_cb(gpointer backend)
 {
 	GigoloBackendGVFSPrivate *priv;
-	priv = GIGOLO_BACKEND_GVFS_GET_PRIVATE(backend);
+	priv = gigolo_backend_gvfs_get_instance_private(GIGOLO_BACKEND_GVFS(backend));
 
 	g_return_val_if_fail(backend != NULL, FALSE);
 
@@ -660,7 +654,7 @@ static void browse_network_mount_ready_cb(GFile *location, GAsyncResult *res, Br
 
 	g_file_mount_enclosing_volume_finish(location, res, &error);
 
-	priv = GIGOLO_BACKEND_GVFS_GET_PRIVATE(bd->self);
+	priv = gigolo_backend_gvfs_get_instance_private(bd->self);
 	priv->browse_counter--;
 
 	if (error != NULL)
@@ -699,7 +693,7 @@ static void browse_network_real(BrowseData *bd)
 	mode = bd->mode;
 	parent = bd->parent;
 	backend = bd->self;
-	priv = GIGOLO_BACKEND_GVFS_GET_PRIVATE(backend);
+	priv = gigolo_backend_gvfs_get_instance_private(backend);
 	priv->browse_counter++;
 
 	file = g_file_new_for_uri(bd->uri);
@@ -714,7 +708,7 @@ static void browse_network_real(BrowseData *bd)
 	{
 		if (g_error_matches(error, G_IO_ERROR, G_IO_ERROR_NOT_MOUNTED))
 		{
-			GMountOperation *op = gigolo_mount_operation_new(bd->parent);
+			GMountOperation *op = gtk_mount_operation_new(bd->parent);
 			/* if the URI wasn't mounted yet, mount it and try again from the mount ready callback */
 			g_file_mount_enclosing_volume(file, G_MOUNT_MOUNT_NONE, op, NULL,
 				(GAsyncReadyCallback) browse_network_mount_ready_cb, bd);
@@ -818,7 +812,7 @@ void gigolo_backend_gvfs_browse_network(GigoloBackendGVFS *backend, GtkWindow *p
 	bd->self = backend;
 	bd->browse_func = browse_network_real;
 
-	priv = GIGOLO_BACKEND_GVFS_GET_PRIVATE(backend);
+	priv = gigolo_backend_gvfs_get_instance_private(backend);
 	priv->browse_counter = 0;
 
 	browse_network_real(bd);
@@ -850,7 +844,7 @@ static void browse_host_real(BrowseData *bd)
 	{
 		if (g_error_matches(error, G_IO_ERROR, G_IO_ERROR_NOT_MOUNTED))
 		{
-			GMountOperation *op = gigolo_mount_operation_new(bd->parent);
+			GMountOperation *op = gtk_mount_operation_new(bd->parent);
 			/* if the URI wasn't mounted yet, mount it and try again from the mount ready callback */
 			g_file_mount_enclosing_volume(file, G_MOUNT_MOUNT_NONE, op, NULL,
 				(GAsyncReadyCallback) browse_network_mount_ready_cb, bd);
